@@ -6,7 +6,7 @@ use std::{
 };
 
 use cargo::{
-    core::{resolver::CliFeatures, Dependency, Workspace, PackageId},
+    core::{resolver::CliFeatures, Workspace},
     ops::{Packages, PublishOpts},
     Config,
 };
@@ -45,7 +45,11 @@ struct WorkspaceDefinition {
     pub members: Vec<String>,
 }
 
-fn update_member_deps(dir: &Path, version: &Version) {
+fn update_member_deps(dir: &Path, version: &Version) -> HashMap<String, HashSet<String>>{
+    // directed acyclic graph to figure out which dependencies
+    // to publish first.
+    let mut graph: HashMap<String, HashSet<String>> = HashMap::new();
+
     let workspace_toml: WorkspaceManifest = toml::from_slice(
         &fs::read_to_string(dir.join("Cargo.toml"))
             .unwrap()
@@ -56,6 +60,7 @@ fn update_member_deps(dir: &Path, version: &Version) {
         let member_dir = dir.join(&member);
         let member_toml = fs::read_to_string(member_dir.join("Cargo.toml")).unwrap();
         let mut member_toml = member_toml.parse::<Document>().unwrap();
+        let mut local_deps = HashSet::new();
 
         member_toml["package"]["version"] = toml_edit::value(version.to_string());
         let deps = member_toml.get_mut("dependencies").map(|deps| deps.as_table_mut());
@@ -66,14 +71,24 @@ fn update_member_deps(dir: &Path, version: &Version) {
                         if let Some(Some(_)) = dep.get("path").map(|dep| dep.as_str()) {
                             // this is a local dependency, so we will need to update the version
                             dep.insert("version", toml_edit::value(version.to_string()));
-                            dbg!(name);
+                            local_deps.insert(name.to_string());
                         }
                     }
                 }
             }
             _ => {}
         }
+
+        let mut file = fs::File::create(member_dir.join("Cargo.toml")).unwrap();
+        file.write_all(member_toml.to_string().as_bytes()).unwrap();
+
+
+        graph.insert(member.to_string(), local_deps);
     }
+
+    // now we have a graph of dependencies, we can figure out which
+    // dependencies to publish first, in the next stage
+    graph
 }
 
 pub fn publish_workspace(dir: &Path, version: &Version) {
@@ -81,62 +96,9 @@ pub fn publish_workspace(dir: &Path, version: &Version) {
     cfg.set_values(cfg.load_values().unwrap()).unwrap();
     cfg.load_credentials().unwrap();
 
-    update_member_deps(dir, version);
-    // let dir = Path::new("/Users/albert/repos/armory/");
+    let graph = update_member_deps(dir, version);
     let workspace_toml = dir.clone().join("Cargo.toml");
-    let mut workspace = Workspace::new(&workspace_toml, &cfg).unwrap();
-
-    // directed acyclic graph to figure out which dependencies
-    // to publish first.
-    let mut graph: HashMap<String, HashSet<String>> = HashMap::new();
-
-    for pkg in workspace.members_mut() {
-        let mut local_deps = HashSet::new();
-        let manifest = pkg.manifest_mut();
-        let package_id = manifest.package_id();
-        let new_id = PackageId::new(
-            &package_id.name().to_string(),
-            version.clone(),
-            package_id.source_id()
-        ).unwrap();
-
-        *manifest.summary_mut() = manifest.summary_mut()
-            .clone()
-            .override_id(new_id)
-            .map_dependencies(|dep| {
-            if dep.source_id().is_path() {
-                local_deps.insert(dep.package_name().to_string());
-
-                // modify the dependency version to the one in the armory.toml
-                // and set any values to the old ones
-                let mut new_dep = Dependency::parse(
-                    &dep.package_name().to_string(),
-                    Some(&version.to_string()),
-                    dep.source_id().clone(),
-                )
-                .unwrap();
-                new_dep.set_default_features(dep.uses_default_features());
-                new_dep.set_features(
-                    dep.features()
-                        .iter()
-                        .map(|feature| feature.to_string())
-                        .collect::<Vec<String>>(),
-                );
-                new_dep.set_kind(dep.kind());
-                new_dep.set_optional(dep.is_optional());
-                new_dep.set_platform(dep.platform().cloned());
-                new_dep.set_public(dep.is_public());
-                if let Some(reg_id) = dep.registry_id() {
-                    new_dep.set_registry_id(reg_id.clone());
-                }
-                new_dep
-            } else {
-                dep
-            }
-        });
-
-        graph.insert(pkg.name().to_string(), local_deps);
-    }
+    let workspace = Workspace::new(&workspace_toml, &cfg).unwrap();
 
     let mut already_published: HashSet<String> = HashSet::new();
 
